import os
import sys
from .templates import main, index, css
import spinne

def main(name):
    print("Creating app...")
    if not os.path.exists(name):
        os.mkdir(name)
    with open(f"{name}/main.py", "w") as f:
        f.write(main.main)
        print("created main file...")
    with open(f"{name}/index.py", "w") as f:
        f.write(index.index)
        print("created index...")

try:
    if sys.argv[1] == "--new" or "-n":
        main(sys.argv[2])
except IndexError:
    print("Usage: spinne --new <name>")


main = """from spinne import Spinne, pageNotFound
import index

app = Spinne("site")

@app.render
def main(route):
    print(route)
    if route == "test":
        return index.index()
    else:
        return pageNotFound()

app.run()"""


import flask

class Spinne():
    """the part you'd use to run your app :)"""
    def __init__(self, name):
        self.name = name
        self.app = flask.Flask(name)

    def run(self, host = "0.0.0.0", port = 5000):
        return self.app.run(host, port)

    def render(self, function):
        @self.app.route("/<route>")
        def locate(route):
            return function(route)
